@@ -13,7 +13,7 @@
 #include "sg_cmds_basic.h"
 
 /*
-*  Copyright (C) 2000-2009 D. Gilbert
+*  Copyright (C) 2000-2010 D. Gilbert
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
@@ -26,7 +26,7 @@
 
 */
 
-static char * version_str = "1.32 20090826";
+static char * version_str = "1.34 20101028";
 
 #define DEF_ALLOC_LEN (1024 * 4)
 #define DEF_6_ALLOC_LEN 252
@@ -522,6 +522,7 @@ static struct page_code_desc pc_desc_disk[] = {
     {0x5, 0x0, "Flexible geometry (obsolete)"},
     {0x7, 0x0, "Verify error recovery"},
     {0x8, 0x0, "Caching"},
+    {0xa, 0xf0, "Application tag"},
     {0xa, 0xf1, "Parallel ATA control (SAT)"},
     {0xa, 0xf2, "Reserved (SATA control) (SAT)"},
     {0xb, 0x0, "Medium types supported (obsolete)"},
@@ -530,10 +531,12 @@ static struct page_code_desc pc_desc_disk[] = {
     {0x10, 0x0, "XOR control"},
     {0x1a, 0xf1, "ATA Power condition"},
     {0x1c, 0x1, "Background control"},
-    {0x1c, 0x2, "Thin provisioning"},
+    {0x1c, 0x2, "Logical block provisioning"},
 };
 
 static struct page_code_desc pc_desc_tape[] = {
+    {0x1, 0x0, "Read-Write error recovery"},
+    {0xa, 0xf0, "Control data protection"},
     {0xf, 0x0, "Data Compression"},
     {0x10, 0x0, "Device configuration"},
     {0x10, 0x1, "Device configuration extension"},
